'use strict';

var React = require('react');

var longestCommonSubsequence = function longestCommonSubsequence(X, Y) {
  var m = X.length;
  var n = Y.length;
  var L = Array(m + 1).fill(null).map(function () {
    return Array(n + 1).fill(0);
  });
  for (var i = 0; i <= m; i++) {
    for (var j = 0; j <= n; j++) {
      if (i === 0 || j === 0) {
        L[i][j] = 0;
      } else if (X[i - 1] === Y[j - 1]) {
        L[i][j] = L[i - 1][j - 1] + 1;
      } else {
        L[i][j] = Math.max(L[i - 1][j], L[i][j - 1]);
      }
    }
  }
  return L;
};

var findDifferences = function findDifferences(str1, str2) {
  var arr1 = str1.split('');
  var arr2 = str2.split('');
  var lcsMatrix = longestCommonSubsequence(arr1, arr2);
  var findResult = function findResult(i, j) {
    var result = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
    while (i > 0 && j > 0) {
      if (arr1[i - 1] === arr2[j - 1]) {
        result.push({
          type: 'common',
          "char": arr1[i - 1]
        });
        i--;
        j--;
      } else if (lcsMatrix[i - 1][j] >= lcsMatrix[i][j - 1]) {
        result.push({
          type: 'removed',
          "char": arr1[i - 1]
        });
        i--;
      } else {
        result.push({
          type: 'added',
          "char": arr2[j - 1]
        });
        j--;
      }
    }
    while (i > 0) {
      result.push({
        type: 'removed',
        "char": arr1[i - 1]
      });
      i--;
    }
    while (j > 0) {
      result.push({
        type: 'added',
        "char": arr2[j - 1]
      });
      j--;
    }
    return result.reverse();
  };
  return findResult(arr1.length, arr2.length);
};

var highlightDifferences = function highlightDifferences(str1, str2, highlightColor) {
  var differences = findDifferences(str1, str2);
  var highlightedStr1 = [];
  var highlightedStr2 = [];
  differences.forEach(function (diff, index) {
    if (diff.type === 'common') {
      highlightedStr1.push( /*#__PURE__*/React.createElement("span", {
        key: "common-".concat(index)
      }, diff["char"]));
      highlightedStr2.push( /*#__PURE__*/React.createElement("span", {
        key: "common-".concat(index)
      }, diff["char"]));
    } else if (diff.type === 'removed') {
      highlightedStr1.push( /*#__PURE__*/React.createElement("span", {
        key: "removed-".concat(index),
        style: {
          color: highlightColor
        }
      }, diff["char"]));
      highlightedStr2.push( /*#__PURE__*/React.createElement("span", {
        key: "removed-".concat(index)
      }));
    } else if (diff.type === 'added') {
      highlightedStr1.push( /*#__PURE__*/React.createElement("span", {
        key: "added-".concat(index)
      }));
      highlightedStr2.push( /*#__PURE__*/React.createElement("span", {
        key: "added-".concat(index),
        style: {
          color: highlightColor
        }
      }, diff["char"]));
    }
  });
  return {
    highlightedStr1: highlightedStr1,
    highlightedStr2: highlightedStr2
  };
};

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".diff-container{background-color:grey;border:1px solid grey;display:flex;gap:16px;padding:16px}.diff-container.vertical{flex-direction:column}.diff-container.horizontal{flex-direction:row}.diff-box{background-color:#fff;flex:1;padding:16px}";
styleInject(css_248z);

var StringDiffHighlighter = function StringDiffHighlighter(_ref) {
  var str1 = _ref.str1,
    str2 = _ref.str2,
    _ref$highlightColor = _ref.highlightColor,
    highlightColor = _ref$highlightColor === void 0 ? 'yellow' : _ref$highlightColor,
    _ref$layout = _ref.layout,
    layout = _ref$layout === void 0 ? 'vertical' : _ref$layout;
  var _highlightDifferences = highlightDifferences(str1, str2, highlightColor),
    highlightedStr1 = _highlightDifferences.highlightedStr1,
    highlightedStr2 = _highlightDifferences.highlightedStr2;
  return /*#__PURE__*/React.createElement("div", {
    className: "diff-container ".concat(layout)
  }, /*#__PURE__*/React.createElement("div", {
    className: "diff-box"
  }, highlightedStr1), /*#__PURE__*/React.createElement("div", {
    className: "diff-box"
  }, highlightedStr2));
};

module.exports = StringDiffHighlighter;
